@@ -5,8 +5,8 @@
 ;; Author: Joost Kremers <joostkremers@fastmail.fm>
 ;; Maintainer: Joost Kremers <joostkremers@fastmail.fm>
 ;; Created: 31 Oct 2009
-;; Package-Version: 20251029.1925
-;; Package-Revision: 8d6e976b465c
+;; Package-Version: 20260114.1255
+;; Package-Revision: 8f46da90228a
 ;; Keywords: text, pandoc
 ;; URL: http://joostkremers.github.io/pandoc-mode/
 
@@ -588,7 +588,7 @@ pandoc is always run on the master file)."
   ;; TODO When the region is active, it might be nice to run pandoc on the
   ;; region but use the master file's settings.
   (interactive "P")
-  (let ((ask (and (listp prefix) (eq (car prefix) 4))))
+  (let ((ask (and (consp prefix) (= (car prefix) 4))))
     (cond
      ((and (not ask)
            (member (pandoc--get 'write) pandoc--pdf-able-formats))
